#!/bin/sh
# Built on TCL v4.1
# Required extensions:
#	compiletc
#	 bison
#	 diffutils
#	 file
#	 findutils
#	 flex
#	 gawk
#	 gcc
#	  gcc_libs
#	  binutils
#	  mpc
#	   mpfr
#	    gmp
#	 grep
#	 m4
#	 make
#	 patch
#	 pkg-config
#	  glib2
#	   libffi
#	  popt
#	 sed
#	 e2fsprogs_base-dev
#	 eglibs_base-dev
#	 fltk_base-dev
#	 freetype_base-dev
#	 gcc_base-dev
#	 imlib2_base-dev
#	 jpeg_base-dev
#	 libpng_base-dev
#	 linux-3.0.1_api_headers
#	 util-linux_base-dev
#	 zlib_base-dev
#	squashfs-tools-4.x
#	tar
#	bluez-dev
#	 bluez
#	  dbus-glib
#	   dbus
#	    expat2
#	  libusb
#	  bluetooth-KERNEL
#	 dbus-glib-dev
#	  dbus-dev
#	   expat2-dev
#	  glib2-dev
#	   libffi-dev
#	 alsa-dev
#	  alsa
#	   alsa-modules-KERNEL
#	    input-joystick-KERNEL
#	    v4l-dvb-KERNEL
#	     i2c-KERNEL
#	   libasound
#	   pci-utils
#	    libpci
#	   ncurses
#	    ncurses-common
#	   alsa-config
#	 gst-plugins-base-dev
#	  gst-plugins-base
#	   gstreamer
#	    libxml2
#	   liboil
#	   libtheora
#	    libogg
#	   libvorbis
#	   udev-lib
#	   iso-codes
#	   cairo
#	    pixman
#	    fontconfig
#	    graphics-libs-1
#	   pango
#	    Xorg-7.6-lib
#	    libxcb
#	   liborc
#	  gstreamer-dev
#	   perl5
#	   libxml2-dev
#	    libxml2-bin
#	  libvorbis-dev
#	   libogg-dev
#	 libusb-dev
#	 libsndfile-dev
#	 cups-dev
#	  cups
#	   libcups
#	pyqt
#	 sip
#	  python
#	   sqlite3
#	   tk
#	    tcl
#	   bzip2-lib
#	   openssl-1.0.0
#	 qt-4.x-xml
#	  qt-4.x-base
#	jack-dev
#	 jack
#	  jack-lib
#	  celt
#	  flac
#	  glibmm
#	   libsigc++
#	  libffado
#	   libiec61883
#	   libraw1394
#	   libxml++
#	  libsamplerate
#	   libsndfile
#	    vorbis-tools
#	     libao
#	     curl
#	     libssl-0.9.8

getTime.sh

installExtension() {
	if [ ! -e /usr/local/tce.installed/$1 ]; then
		echo "Installing "$1" ..."
		
		if [ -e $TCEDIR/optional/$1.tcz ]; then
			tce-load -i $1
		else
			tce-load -wi $1
		fi
		
		[ ! -e /usr/local/tce.installed/$1 ] && echo "Error: Extension "$1" not installed! Aborting" && exit
	fi
}

createExtension() {
	mksquashfs $1 $1.tcz -noappend
	[ ! -e $1.tcz ] && echo "Error: "$1".tcz not created! Aborting" && exit
}

unpackSrc() {
	#unpack source
	if [ -e $1.tar.bz2 ]; then
		tar -jxf $1.tar.bz2
	elif [ -e $1.tb2 ]; then
		tar -jxf $1.tb2
	elif [ -e $1.tbz ]; then
		tar -jxf $1.tbz
	elif [ -e $1.tar.gz ]; then
		tar -zxf $1.tar.gz
	elif [ -e $1.tgz ]; then
		tar -zxf $1.tgz
	elif [ -e $1.tar.xz ]; then
		tar -Jxf $1.tar.xz
	elif [ -e $1.txz ]; then
		tar -Jxf $1.txz
	elif [ -e $1.tar.lzma ]; then
		tar -xf $1.tar.lzma --lzma
	elif [ -e $1.tlz ]; then
		tar -xf $1.tlz --lzma
	else
		echo "Source "$1" not found! Aborting" && exit
	fi
}

# Install these extensions automagically
export EXTS="compiletc
squashfs-tools-4.x
tar
bluez-dev
pyqt
jack-dev"

export TCEDIR=`cat /opt/.tce_dir`
export CFLAGS="-march=i486 -mtune=i686 -Os -pipe"
export CXXFLAGS=$CFLAGS" -fno-exceptions -fno-rtti"
export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig:/usr/lib/pkgconfig
export EXTNAME="qtsixa"
export EXTNAME2="sixad"
export VER="-1.5.1"
export DESTDIR=`pwd`/$EXTNAME
export PKGNAME="QtSixA"$VER"-src"

for f in $EXTS; do
	installExtension $f
done

unpackSrc $PKGNAME

export PKGNAME="QtSixA"$VER

mkdir -p $EXTNAME/usr/local/bin $EXTNAME/usr/local/share/applications $EXTNAME2/usr/local/bin

cd $PKGNAME

# adjust for TC
for f in $(grep -lr '\/usr\/' *); do
	sed -i 's!/usr!/usr/local!g' $f
done
for f in $(grep -lr '\/bin\/env' *); do
	sed -i 's!/usr/local/bin/env!/usr/bin/env!g' $f
done
for f in $(grep -lr '\/etc\/' *); do
	sed -i 's!/etc!/usr/local/etc!g' $f
done
for f in $(grep -lr '\/var\/' *); do
	sed -i 's!/var!/usr/local/var!g' $f
done
for f in $(grep -lr '\/lib\/udev' *); do
	sed -i 's!/lib/udev!/etc/udev!g' $f
done
for f in $(grep -lr 'init.d\/bluetooth' *); do
	sed -i 's!init.d/bluetooth!init.d/bluez!g' $f
done
for f in $(grep -lr 'ps -e' *); do
	sed -i 's!ps -e | grep!pidof!g' $f
done

make && make install DESTDIR=$DESTDIR || exit

cd $DESTDIR

echo "X-FullPathIcon=/usr/local/share/pixmaps/$EXTNAME.png" >> usr/local/share/applications/$EXTNAME.desktop

sudo chown tc:staff usr/local/bin/*
sudo chown tc:staff usr/local/sbin/*
sudo chmod 755 usr/local/bin/*
sudo chmod 755 usr/local/sbin/*

strip --strip-unneeded usr/local/bin/*
strip --strip-unneeded usr/local/sbin/*

mv usr/local/bin/$EXTNAME2 ../$EXTNAME2/usr/local/bin/
mv usr/local/bin/$EXTNAME2-jack ../$EXTNAME2/usr/local/bin/
mv usr/local/sbin ../$EXTNAME2/usr/local/
mv usr/local/etc ../$EXTNAME2/usr/local/

cp -a usr/local/share/$EXTNAME/icons/$EXTNAME.png usr/local/share/pixmaps/$EXTNAME.png

rm -rf var

cd ../$EXTNAME2

echo '#!/bin/bash
#
# sixad Userspace Daemon start/stop script
#	OS:	Tinycore v4.x
#	Author: robc

killDbusBlocker() {
	export TOKILL=`ps | grep sixad-dbus-blocker | grep -v grep | cut -f 1 -d " "`
	for f in $TOKILL; do
		kill $f
	done
}

status() {
	if [ `pidof sixad-bin` ]; then
		echo "sixad Daemon is running."
		exit 0
	else
		echo "sixad is not running."
		exit 1
	fi
}

start() {
	killDbusBlocker
	if [ ! `lsmod | grep joydev` ]; then
		modprobe joydev && echo "Loading joydev module."
	fi
	if [ `pidof sixad-bin` ]; then
		echo "sixad Daemon is already running."
	else
		OPTS=${OPTS:-"-s"}
		/usr/local/etc/init.d/bluez start || exit 2
		/usr/local/etc/init.d/dbus start || exit 2
		/usr/local/etc/init.d/haldaemon start || exit 2
		sixad $OPTS &
		echo "sixad Daemon is starting."
	fi
}

stop() {
	if [ `pidof sixad-bin` ]; then
		sixad --stop && echo "sixad Daemon stopped."
		killDbusBlocker
	else
		echo "sixad Daemon was not running."
	fi
}

case $1 in
	status) status
		;;
	stop) stop
		;;
	start) OPTS=${@#$1}; start
		;;
	restart) stop; OPTS=${@#$1}; start
		;;
	*) echo "Usage: /usr/local/etc/init.d/sixad [start [OPTIONS]|stop|restart [OPTIONS]|status]"
		;;
esac' > usr/local/etc/init.d/$EXTNAME2

chmod 755 usr/local/etc/init.d/$EXTNAME2

cd ..

createExtension $EXTNAME
createExtension $EXTNAME2

rm -rf $PKGNAME $EXTNAME $EXTNAME2

# Create extension support files and test
installExtension "submitqc4"

submitqc4
